==> cbs-panorama-1.0.2.tgz: package/index.js <==
module.exports = AppModule = {
    Panorama: {
        // Global variables to store configuration
        iFrameId: null,
        iFrameSource: null,
        closeable: null,
        closeButtonId: null,
        clickableMap: null,
        keyboardMovementEnabled: null,
        panoramaToggleId: null,
        markerEnabled: null,
        markerId: 'view-cone-marker',
        markerImage: null,
        // Variable to store whether the panorama is loaded or not
        panoramaLoaded: false,
        // Opens the panorama at the location x,y
        OpenPanoramaOnLocation: function (x, y) {
            // Get the frame
            const iframe = document.getElementById(this.iFrameId);
            // If the frame is closed
            if (iframe.hidden == true) {
                // Open iframe
                this.OpenPanoramaFrame();
            }
            // Then, open the coordinates
            this.OpenCoordinates(x, y);
        },
        // Opens the new coordinates on an already open panorama
        OpenCoordinates: function (x, y) {
            // Store this before timeout
            const panorama = this;
            // Wait until iframe is loaded
            if (panorama.panoramaLoaded == false) {
                timer = setTimeout(function () {
                    panorama.OpenCoordinates(x, y);
                }, 50);
            }
            else {
                // When the frame is loaded post message to open new coordinates
                document.getElementById(panorama.iFrameId).contentWindow.postMessage({ data: { coordinates: [x, y] } }, '*');
            }

        },
        // Opens the panorama iframe
        OpenPanoramaFrame: function () {
            // Get the frame
            const iframe = document.getElementById(this.iFrameId);
            // Fill in its source
            iframe.src = this.iFrameSource;
            // Unhide it
            iframe.hidden = false;
            // Unhide the close button if it exists
            if (this.closeButtonId != null) {
                document.getElementById(this.closeButtonId).hidden = false;
            }
            // If panorama is closeable and closeButton is not null
            if (this.closeable == true && this.closeButtonId != null) {
                // Add an eventlistener for the close button
                const closeButton = document.getElementById(this.closeButtonId);
                closeButton.addEventListener('click', this.CloseButtonEventHandler);
                closeButton.panorama = this;
            }
        },
        // Listens to buttons and fires event accordingly
        MoveOnKeyPress: function () {
            // Store this before event
            const panorama = this;
            window.addEventListener('keydown', function (event) {
                // Initialize direction
                let direction;
                // If frame is loaded
                if (panorama.panoramaLoaded == true) {
                    // Fill in direction according to keys
                    if (event.key === 'ArrowUp' || event.key == 'w') {
                        direction = 'front';
                    }
                    else if (event.key == 'ArrowDown' || event.key == 's') {
                        direction = 'back';
                    }
                    else if (event.key == 'ArrowRight' || event.key == 'd') {
                        direction = 'right';
                    }
                    else if (event.key == 'ArrowLeft' || event.key == 'a') {
                        direction = 'left';
                    }
                    // If the key was valid then send a message including direction
                    if (direction != null) {
                        document.getElementById(panorama.iFrameId).contentWindow.postMessage({ data: { direction: direction } }, '*');
                    }
                }
            });
        },
        // Event handler for the close button
        CloseButtonEventHandler: function (event) {
            const panorama = event.currentTarget.panorama;
            // Get the close button
            const closeButton = document.getElementById(panorama.closeButtonId);
            // Hide the close button
            closeButton.hidden = 'hidden';
            // Get the iframe
            const iframe = document.getElementById(panorama.iFrameId);
            // Empty its source so it doesnt load
            iframe.src = '';
            // Hide it
            iframe.hidden = 'hidden';
            // Get the vision cone
            const marker = document.getElementById(panorama.markerId);
            if (marker != null) {
                // Remove it
                marker.parentElement.removeChild(marker);
            }
            // Store that the panorama is deloaded
            panorama.panoramaLoaded = false;
            // Remove event listener
            event.currentTarget.removeEventListener('click', panorama.CloseButtonEventHandler);
        },
        // Configure MapLibre map for panorama usage, call this method in map.onload
        ConfigureMapLibreMap(map, maplibregl) {
            // If keyboard movement is on
            if (this.keyboardMovementEnabled == true) {
                // Disable map keyboard controls
                map.keyboard.disable();
            }
            // Store this before events
            const panorama = this;
            // If map is clickable
            if (this.clickableMap == true) {
                // Open panorama on click location
                map.on('click', function (e) {
                    // If checkbox is checked
                    if (document.getElementById(panorama.panoramaToggleId).checked == true) {
                        // Open panorama on location
                        panorama.OpenPanoramaOnLocation(e.lngLat.lng, e.lngLat.lat);
                    }
                })
            }
            // If marker is enabled
            if (panorama.markerEnabled == true) {
                // When marker gets update as message event
                window.addEventListener('message', function (event) {
                    if (event.data.data.angle != undefined && event.data.data.coordinates != undefined) {
                        // Get angle from message
                        angle = event.data.data.angle;
                        // Get raw coordintes from message in 3857 from message and transform them to 4326
                        coordinates = [event.data.data.coordinates[0], event.data.data.coordinates[1]];
                        // Get the marker
                        var marker = document.getElementById(panorama.markerId);
                        // If there is a marker
                        if (marker != null) {
                            // Get its coordinates
                            var markerCoordinates = marker.dataset.coordinates.split(',').map(Number);
                            // If the new coordinates are different than the markers coordinates
                            if (coordinates[0] != markerCoordinates[0] || coordinates[1] != markerCoordinates[1]) {
                                // Center map
                                map.flyTo({ center: coordinates });
                            }
                            // Remove marker
                            marker.parentElement.removeChild(marker);
                        }
                        // Create new marker
                        const element = document.createElement('div');
                        element.id = panorama.markerId;
                        element.dataset.coordinates = coordinates;
                        element.style = 'width:68px;height:150px;';
                        element.style.backgroundImage = "url(" + panorama.markerImage + ")";
                        new maplibregl.Marker(element).setLngLat(coordinates).setRotation(angle).addTo(map);
                    }
                })
            }
        },
        // Configure Panorama iFrameId is html id of the iframe, close button id is the html id of the close button, if marker is rendered on map markerId is the html id of the marker
        ConfigurePanorama: function (properties) {
            // Initialize global variables
            this.iFrameId = properties.iFrameElementId;
            this.iFrameSource = properties.iFrameElementSrc;
            this.closeable = properties.closeable;
            this.closeButtonId = properties.closeButtonElementId;
            this.clickableMap = properties.clickableMap;
            this.keyboardMovementEnabled = properties.keyboardMoevable;
            this.panoramaToggleId = properties.panoramaCheckBoxElementId;
            this.markerEnabled = properties.markerEneabled;
            this.markerImage = properties.viewConeImageUrl;
            const panorama = this;
            // Catch the panorama loaded message
            window.addEventListener('message', function (event) {
                if (event.data.data.load == true) {
                    panorama.panoramaLoaded = true;
                }
            });
            // If configuration allows keyboard movement
            if (this.keyboardMovementEnabled == true) {
                // Add key events
                this.MoveOnKeyPress();
            }
        }
    }
}

==> cbs-panorama-1.0.4.tgz: package/index.js <==
module.exports = AppModule = {
    Panorama: {
        // Global variables to store configuration
        iFrameId: null,
        iFrameSource: null,
        closeable: null,
        closeButtonId: null,
        clickableMap: null,
        keyboardMovementEnabled: null,
        panoramaToggleId: null,
        markerEnabled: null,
        markerId: 'view-cone-marker',
        // Variable to store whether the panorama is loaded or not
        panoramaLoaded: false,
        // Opens the panorama at the location x,y
        OpenPanoramaOnLocation: function (x, y) {
            // Get the frame
            const iframe = document.getElementById(this.iFrameId);
            // If the frame is closed
            if (iframe.hidden == true) {
                // Open iframe
                this.OpenPanoramaFrame();
            }
            // Then, open the coordinates
            this.OpenCoordinates(x, y);
        },
        // Opens the new coordinates on an already open panorama
        OpenCoordinates: function (x, y) {
            // Store this before timeout
            const panorama = this;
            // Wait until iframe is loaded
            if (panorama.panoramaLoaded == false) {
                timer = setTimeout(function () {
                    panorama.OpenCoordinates(x, y);
                }, 50);
            }
            else {
                // When the frame is loaded post message to open new coordinates
                document.getElementById(panorama.iFrameId).contentWindow.postMessage({ data: { coordinates: [x, y] } }, '*');
            }

        },
        // Opens the panorama iframe
        OpenPanoramaFrame: function () {
            // Get the frame
            const iframe = document.getElementById(this.iFrameId);
            // Fill in its source
            iframe.src = this.iFrameSource;
            // Unhide it
            iframe.hidden = false;
            // Unhide the close button if it exists
            if (this.closeButtonId != null) {
                document.getElementById(this.closeButtonId).hidden = false;
            }
            // If panorama is closeable and closeButton is not null
            if (this.closeable == true && this.closeButtonId != null) {
                // Add an eventlistener for the close button
                const closeButton = document.getElementById(this.closeButtonId);
                closeButton.addEventListener('click', this.CloseButtonEventHandler);
                closeButton.panorama = this;
            }
        },
        // Listens to buttons and fires event accordingly
        MoveOnKeyPress: function () {
            // Store this before event
            const panorama = this;
            window.addEventListener('keydown', function (event) {
                // Initialize direction
                let direction;
                // If frame is loaded
                if (panorama.panoramaLoaded == true) {
                    // Fill in direction according to keys
                    if (event.key === 'ArrowUp' || event.key == 'w') {
                        direction = 'front';
                    }
                    else if (event.key == 'ArrowDown' || event.key == 's') {
                        direction = 'back';
                    }
                    else if (event.key == 'ArrowRight' || event.key == 'd') {
                        direction = 'right';
                    }
                    else if (event.key == 'ArrowLeft' || event.key == 'a') {
                        direction = 'left';
                    }
                    // If the key was valid then send a message including direction
                    if (direction != null) {
                        document.getElementById(panorama.iFrameId).contentWindow.postMessage({ data: { direction: direction } }, '*');
                    }
                }
            });
        },
        // Event handler for the close button
        CloseButtonEventHandler: function (event) {
            const panorama = event.currentTarget.panorama;
            // Get the close button
            const closeButton = document.getElementById(panorama.closeButtonId);
            // Hide the close button
            closeButton.hidden = 'hidden';
            // Get the iframe
            const iframe = document.getElementById(panorama.iFrameId);
            // Empty its source so it doesnt load
            iframe.src = '';
            // Hide it
            iframe.hidden = 'hidden';
            // Get the vision cone
            const marker = document.getElementById(panorama.markerId);
            if (marker != null) {
                // Remove it
                marker.parentElement.removeChild(marker);
            }
            // Store that the panorama is deloaded
            panorama.panoramaLoaded = false;
            // Remove event listener
            event.currentTarget.removeEventListener('click', panorama.CloseButtonEventHandler);
        },
        // Configure MapLibre map for panorama usage, call this method in map.onload
        ConfigureMapLibreMap(map, maplibregl) {
            // If keyboard movement is on
            if (this.keyboardMovementEnabled == true) {
                // Disable map keyboard controls
                map.keyboard.disable();
            }
            // Store this before events
            const panorama = this;
            // If map is clickable
            if (this.clickableMap == true) {
                // Open panorama on click location
                map.on('click', function (e) {
                    // If checkbox is checked
                    if (document.getElementById(panorama.panoramaToggleId).checked == true) {
                        // Open panorama on location
                        panorama.OpenPanoramaOnLocation(e.lngLat.lng, e.lngLat.lat);
                    }
                })
            }
            // If marker is enabled
            if (panorama.markerEnabled == true) {
                // When marker gets update as message event
                window.addEventListener('message', function (event) {
                    if (event.data.data.angle != undefined && event.data.data.coordinates != undefined) {
                        // Get angle from message
                        angle = event.data.data.angle;
                        // Get raw coordintes from message in 3857 from message and transform them to 4326
                        coordinates = [event.data.data.coordinates[0], event.data.data.coordinates[1]];
                        // Get the marker
                        var marker = document.getElementById(panorama.markerId);
                        // If there is a marker
                        if (marker != null) {
                            // Get its coordinates
                            var markerCoordinates = marker.dataset.coordinates.split(',').map(Number);
                            // If the new coordinates are different than the markers coordinates
                            if (coordinates[0] != markerCoordinates[0] || coordinates[1] != markerCoordinates[1]) {
                                // Center map
                                map.flyTo({ center: coordinates });
                            }
                            // Remove marker
                            marker.parentElement.removeChild(marker);
                        }
                        // Create new marker
                        const element = document.createElement('div');
                        element.id = panorama.markerId;
                        element.dataset.coordinates = coordinates;
                        element.style = 'width:68px;height:150px;';
                        element.style.backgroundImage = './src/panoramaCone.png';
                        new maplibregl.Marker(element).setLngLat(coordinates).setRotation(angle).addTo(map);
                    }
                })
            }
        },
        // Configure Panorama iFrameId is html id of the iframe, close button id is the html id of the close button, if marker is rendered on map markerId is the html id of the marker
        ConfigurePanorama: function (properties) {
            // Initialize global variables
            this.iFrameId = properties.iFrameElementId;
            this.iFrameSource = properties.iFrameElementSrc;
            this.closeable = properties.closeable;
            this.closeButtonId = properties.closeButtonElementId;
            this.clickableMap = properties.clickableMap;
            this.keyboardMovementEnabled = properties.keyboardMoevable;
            this.panoramaToggleId = properties.panoramaCheckBoxElementId;
            this.markerEnabled = properties.markerEneabled;
            const panorama = this;
            // Catch the panorama loaded message
            window.addEventListener('message', function (event) {
                if (event.data.data.load == true) {
                    panorama.panoramaLoaded = true;
                }
            });
            // If configuration allows keyboard movement
            if (this.keyboardMovementEnabled == true) {
                // Add key events
                this.MoveOnKeyPress();
            }
        }
    }
}
